@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2012 OpenStack LLC.
 # All Rights Reserved.
@@ -19,6 +18,9 @@ from __future__ import print_function
 
 import argparse
 import json
+import os
+import uuid
+import yaml
 
 from oslo_utils import importutils
 
@@ -178,3 +180,23 @@ def common_filters(limit=None, sort_key=None, sort_dir=None):
     if sort_dir is not None:
         filters.append('sort_dir=%s' % sort_dir)
     return filters
+
+
+def is_uuid_like(val):
+    """Returns validation of a value as a UUID.
+
+    For our purposes, a UUID is a canonical form string:
+    aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa
+
+    """
+    try:
+        return str(uuid.UUID(val)) == val
+    except (TypeError, ValueError, AttributeError):
+        return False
+
+
+def serialize_file_to_dict(filename):
+    filename = os.path.expanduser(filename)
+    with open(filename, "rb") as stream:
+        scope = yaml.safe_load(stream.read())
+    return scope
