@@ -1,4 +1,3 @@
-# -*- encoding: utf-8 -*-
 # Copyright (c) 2016 b<>com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,7 +14,7 @@
 # limitations under the License.
 
 import json
-from openstackclient.common import utils
+from osc_lib import utils
 
 from watcherclient._i18n import _
 from watcherclient.common import command
